.. _cwl:

CWL in Toil
===========

The Common Workflow Language (CWL) is an emerging standard for writing workflows
that are portable across multiple workflow engines and platforms.
Toil has full support for the CWL v1.0, v1.1, and v1.2 standards.

You can use Toil to :ref:`run CWL workflows <runCwl>` or develop and test new ones.
